@@ -126,7 +126,7 @@ module Async
 					self.sleep
 					
 					if self.status?(:ready)
-						Console.logger.debug(self) do |buffer|
+						Console.debug(self) do |buffer|
 							buffer.puts "All ready:"
 							@state.each do |child, state|
 								buffer.puts "\t#{child.inspect}: #{state}"
@@ -141,7 +141,7 @@ module Async
 			# Stop the children instances.
 			# @parameter timeout [Boolean | Numeric] Whether to stop gracefully, or a specific timeout.
 			def stop(timeout = true)
-				Console.debug(self, "Stopping container...", timeout: timeout)
+				Console.info(self, "Stopping container...", timeout: timeout)
 				@running = false
 				@group.stop(timeout)
 				
