@@ -129,6 +129,15 @@ module Async
 							end
 						end
 					end
+					
+					# Wait until a "ready" message is received from the child process.
+					def wait_until_ready
+						while message = receive
+							if message[:ready] == true
+								return
+							end
+						end
+					end
 				end
 			end
 		end
